from pydantic import UUID4

from galileo_core.helpers.group_project import share_project_with_group as core_share_project_with_group
from galileo_core.schemas.core.collaboration_role import CollaboratorRole
from galileo_core.schemas.core.group_project import GroupProjectCollaboratorResponse
from promptquality.types.config import PromptQualityConfig


def share_project_with_group(
    project_id: UUID4, group_id: UUID4, role: CollaboratorRole = CollaboratorRole.viewer
) -> GroupProjectCollaboratorResponse:
    config = PromptQualityConfig.get()
    return core_share_project_with_group(project_id=project_id, group_id=group_id, role=role, config=config)



from os import environ
from typing import Any, Optional

from promptquality.types.config import PromptQualityConfig
from promptquality.utils.logger import logger


def login(console_url: Optional[str] = None, **kwargs: Any) -> PromptQualityConfig:
    """
    Login to Galileo.

    By default, this will login to the Galileo Console (set as environemnt variable or passed as an argument) using the
    credentials provided in the environment variables GALILEO_USERNAME and GALILEO_PASSWORD or GALILEO_API_KEY. If the
    credentials are not provided in the environment variables, they can be passed in as keyword arguments (username and
    password or api_key).

    This function is optional and only required if you want to login using args that are not set as environment variables.
    """
    if console_url:
        if environ.get("GALILEO_CONSOLE_URL") == console_url:
            logger.warning(
                "The console URL provided is the same as the one in the environment variable GALILEO_CONSOLE_URL and is not required to be passed in."
            )
        kwargs["console_url"] = console_url
    return PromptQualityConfig.get(**kwargs)



from typing import Optional

from pydantic import UUID4

from galileo_core.helpers.project import get_project as core_get_project
from galileo_core.schemas.core.project import ProjectResponse, ProjectType
from promptquality.types.config import PromptQualityConfig


def get_project(project_id: Optional[UUID4] = None, project_name: Optional[str] = None) -> Optional[ProjectResponse]:
    config = PromptQualityConfig.get()
    return core_get_project(
        project_id=project_id, project_name=project_name, project_type=ProjectType.llm_monitor, config=config
    )



from uuid import UUID

from galileo_core.helpers.dataset import create_dataset as core_create_dataset
from galileo_core.helpers.dataset import get_dataset_content as core_get_dataset_content
from galileo_core.helpers.dataset import list_datasets as core_list_datasets
from galileo_core.schemas.core.dataset import Dataset, DatasetType
from promptquality.types.config import PromptQualityConfig


def create_dataset(dataset: DatasetType) -> Dataset:
    config = PromptQualityConfig.get()
    return core_create_dataset(dataset=dataset, config=config)


def get_dataset_content(dataset_id: UUID) -> list[dict]:
    config = PromptQualityConfig.get()
    return core_get_dataset_content(dataset_id=dataset_id, config=config)


def list_datasets() -> list[Dataset]:
    config = PromptQualityConfig.get()
    return core_list_datasets(config=config)



from pydantic import UUID4

from galileo_core.helpers.user_project import share_project_with_user as core_share_project_with_user
from galileo_core.schemas.core.collaboration_role import CollaboratorRole
from galileo_core.schemas.core.user_project import UserProjectCollaboratorResponse
from promptquality.types.config import PromptQualityConfig


def share_project_with_user(
    project_id: UUID4, user_id: UUID4, role: CollaboratorRole = CollaboratorRole.viewer
) -> UserProjectCollaboratorResponse:
    config = PromptQualityConfig.get()
    return core_share_project_with_user(project_id=project_id, user_id=user_id, role=role, config=config)



from typing import Optional

from pydantic import UUID4

from galileo_core.helpers.group import add_users_to_group as core_add_users_to_group
from galileo_core.helpers.group import create_group as core_create_group
from galileo_core.helpers.group import list_groups as core_list_groups
from galileo_core.schemas.core.group import AddGroupMemberResponse, CreateGroupResponse
from galileo_core.schemas.core.group_role import GroupRole
from galileo_core.schemas.core.group_visibility import GroupVisibility
from promptquality.types.config import PromptQualityConfig


def add_users_to_group(
    group_id: UUID4, user_ids: list[UUID4], role: GroupRole = GroupRole.member
) -> list[AddGroupMemberResponse]:
    config = PromptQualityConfig.get()
    return core_add_users_to_group(group_id=group_id, user_ids=user_ids, role=role, config=config)


def create_group(
    name: str, description: Optional[str] = None, visibility: GroupVisibility = GroupVisibility.public
) -> CreateGroupResponse:
    config = PromptQualityConfig.get()
    return core_create_group(name=name, description=description, visibility=visibility, config=config)


def list_groups() -> list[CreateGroupResponse]:
    config = PromptQualityConfig.get()
    return core_list_groups(config=config)



from typing import Optional

from pydantic import UUID4

from galileo_core.helpers.user import get_current_user as core_get_current_user
from galileo_core.helpers.user import invite_users as core_invite_users
from galileo_core.helpers.user import list_users as core_list_users
from galileo_core.schemas.core.auth_method import AuthMethod
from galileo_core.schemas.core.user import User
from galileo_core.schemas.core.user_role import UserRole
from promptquality.types.config import PromptQualityConfig


def get_current_user() -> User:
    config = PromptQualityConfig.get()
    return core_get_current_user(config=config)


def invite_users(
    emails: list[str],
    role: UserRole = UserRole.user,
    group_ids: Optional[list[UUID4]] = None,
    auth_method: AuthMethod = AuthMethod.email,
) -> None:
    config = PromptQualityConfig.get()
    return core_invite_users(emails=emails, role=role, group_ids=group_ids, auth_method=auth_method, config=config)


def list_users() -> list[User]:
    config = PromptQualityConfig.get()
    return core_list_users(config=config)



from datetime import datetime
from typing import Optional

from pydantic import UUID4

from galileo_core.helpers.api_key import create_api_key as core_create_api_key
from galileo_core.helpers.api_key import delete_api_key as core_delete_api_key
from galileo_core.helpers.api_key import list_api_keys as core_list_api_keys
from galileo_core.schemas.core.api_key import ApiKeyResponse, CreateApiKeyResponse
from galileo_core.schemas.core.collaboration_role import CollaboratorRole
from promptquality.types.config import PromptQualityConfig


def create_api_key(
    description: str,
    expires_at: Optional[datetime] = None,
    project_id: Optional[UUID4] = None,
    project_role: Optional[CollaboratorRole] = None,
) -> CreateApiKeyResponse:
    config = PromptQualityConfig.get()
    return core_create_api_key(
        description=description, expires_at=expires_at, project_id=project_id, project_role=project_role, config=config
    )


def list_api_keys() -> list[ApiKeyResponse]:
    config = PromptQualityConfig.get()
    return core_list_api_keys(config=config)


def delete_api_key(api_key_id: UUID4) -> None:
    config = PromptQualityConfig.get()
    return core_delete_api_key(api_key_id=api_key_id, config=config)



from typing import Optional

from pydantic import UUID4

from promptquality.types.config import PromptQualityConfig
from promptquality.types.pagination import PaginationDefaults
from promptquality.types.rows import GetRowsRequest, PromptRow, PromptRows


def get_rows(
    project_id: Optional[UUID4] = None,
    run_id: Optional[UUID4] = None,
    task_type: Optional[int] = None,
    starting_token: int = PaginationDefaults.starting_token,
    limit: int = PaginationDefaults.limit,
) -> list[PromptRow]:
    config = PromptQualityConfig.get()
    project_id = project_id or config.current_project_id
    if not project_id:
        raise ValueError("project_id must be provided")
    run_id = run_id or config.current_run_id
    if not run_id:
        raise ValueError("run_id must be provided")
    task_type = task_type or config.current_run_task_type
    if not task_type:
        raise ValueError("task_type must be provided")
    rows_json = config.pq_api_client.get_rows(
        GetRowsRequest(
            project_id=project_id, run_id=run_id, task_type=task_type, starting_token=starting_token, limit=limit
        )
    )
    rows_response = PromptRows.model_validate(rows_json)
    # If we paginated, return the rows + the rows from the next page.
    if rows_response.paginated:
        assert rows_response.next_starting_token is not None, (
            "next_starting_token is None even though paginated is True."
        )
        return rows_response.rows + get_rows(
            project_id=project_id,
            run_id=run_id,
            starting_token=rows_response.next_starting_token,
            limit=limit,
            task_type=task_type,
        )
    # If we didn't paginate, return the rows.
    else:
        return rows_response.rows



from typing import Optional

from pydantic import UUID4, BaseModel, ConfigDict, Field

from promptquality.types.pagination import PaginationResponseMixin


class RegisteredScorer(BaseModel):
    # The aliases are what the API returns as a part of the response.
    id: UUID4 = Field(alias="registered_scorer_id")
    name: str = Field(alias="metric_name")
    score_type: Optional[str] = None
    scoreable_node_types: Optional[list[str]] = None

    model_config = ConfigDict(populate_by_name=True)


class ListRegisteredScorers(PaginationResponseMixin):
    scorers: list[RegisteredScorer]
